/****************************************************************************************************/
/*
\file       LCD_HAL.h
\author     Freescale Semiconductor
\author     Technical Information Center (TIC)
\version    1.0
\date		August 2009      
*/
/****************************************************************************************************/
/* Services performed by FREESCALE in this matter are performed AS IS and without any warranty.		*/
/* CUSTOMER retains the final decision relative to the total design and functionality of the end	*/
/* product.                                                                                     	*/
/* FREESCALE neither guarantees nor will be held liable by CUSTOMER for the success of this project.*/
/*                                                                                                  */
/* FREESCALE disclaims all warranties, express, implied or statutory including, but not limited to, */
/* implied warranty of merchantability or fitness for a particular purpose on any hardware,         */
/* software ore advise supplied to the project by FREESCALE, and or any product resulting from      */
/* FREESCALE services.                                                                              */
/* In no event shall FREESCALE be liable for incidental or consequential damages arising out of     */
/* this agreement. CUSTOMER agrees to hold FREESCALE harmless against any and all claims demands or */
/* actions by anyone on account of any damage,or injury, whether commercial, contractual, or        */
/* tortuous, rising directly or indirectly as a result of the advise or assistance supplied CUSTOMER*/ 
/* in connectionwith product, services or goods supplied under this Agreement.                      */
/*                                                                                                  */
/****************************************************************************************************/

/*****************************************************************************************************
* Module definition against multiple inclusion
*****************************************************************************************************/
#ifndef __LCD_HAL_H
#define __LCD_HAL_H

/*****************************************************************************************************
* Include files
*****************************************************************************************************/

/** Variable types and common definitions */
#include "FslTypes.h"

//#define MC9RS08LE4
//#define MC9RS08LA8
#define MC9S08LL16
//#define MC9S08LG32
//#define MCF51EM256
/*****************************************************************************************************
* Declaration of project wide TYPES
*****************************************************************************************************/

/*****************************************************************************************************
* Definition of project wide VARIABLES
*****************************************************************************************************/

/*****************************************************************************************************
* Definition of project wide MACROS / #DEFINE-CONSTANTS 
*****************************************************************************************************/

/*^^^^^^^^^^^^^^^^      LCD Configuration                        ^^^^^^^^^^^^^^^^^^^^^^^^*/

#define _LCDBACKPLANES			(8)				// # of backplanes  
#define _LCDCLKSOURCE			(0)				// 0 -- External clock       1 --  Alternate clock  (Internal)

#define _LCDCLKPSL				(4)				//  Clock divider to generate the LCD Waveforms

#define _LCDCPSEL				(1)				//0 -- Resistor network   1 -- Charge pump  
#define _LCDVSUPPLY				(3)				//0  --  VLL2 from VDD    1 --   VLL3 from VDD  2 -- VLL1 from VLCD  3 -- VLL3 external 
#define _LCDLOADADJUST			(0)				//Charge pump 		0 -- 8000 pf 1 -- 6000 pf  2 -- 4000 pf  3 -- 2000 pf
                                                //Resistor Network	0 -- 2000 pf 1 -- 2000 pf  2 -- 8000 pf   3 -- 8000 pf 

#define _LCDFRAMEINTERRUPT		(0)             //0 Disabel  Interrupt 1 Enable aLCD interrupt that coincides with the LCD frame frequency

#define _LCDBLINKRATE 			(0)				//Blink frequecy preescaler  any number between 0-7

#define _CHARNUM				(9)				// Number of characters on the display

#define _LCDTYPE				(2)				//Number of LCDWF  nedded  to drive one character 

/*^^^^^^^^^^^^^^^^      LCD Hardware Connection 			 ^^^^^^^^^^^^^^^^^^^^^^^^*/

#define EnableLCDpins(RegNum,Mask)		LCDPEN##RegNum = Mask
#define EnableBackplanes(RegNum, Mask)	LCDBPEN##RegNum = Mask   
#define SetBackplane(ComNum, LCDn)		LCDWF##LCDn  = (1 <<  (##ComNum##))
#define CharacterPlace(LCDn)        	LCDWF##LCDn
#define AllSegmentsON(LCDn,ComMask)		LCDWF##LCDn = ComMask
#define SymbolON(LCDn, BitNumber)		LCDWF##LCDn = (gu8RamBuffer[LCDn] |= (1<< BitNumber))
#define SymbolOFF(LCDn, BitNumber)		LCDWF##LCDn = (gu8RamBuffer[LCDn] &= ~(1<< BitNumber))
#define MapSegment(BitNumber)  			(1<<(##BitNumber##)) 
#define LCDWFRef          				LCDWF0
#define LCD_AlphanumericPlace(Place)	bLCD_CharPosition=_LCDTYPE*##(Place-1)
/*
EnableLCDpins
Habilitate the mcu pin with the characteristics of a LCD pin 
param: RegNum -- Number of register to write     Mask --- Mask that habilitate the LCDx pins
*/
	#define _PEN0()       EnableLCDpins (0,255)
	#define _PEN1()       EnableLCDpins (1,255)
	#define _PEN2()       EnableLCDpins (2,255)
	#define _PEN3()       EnableLCDpins (3,255)

/* 
EnableBackplanes
Enable the LCD pin like a Backplane functionality  
param: RegNum -- Number of register to write     LCDpin --- LCDn pin number that the Backplane it's connected 
*/
	#define   _BPEN0()        EnableBackplanes (0, 219)
	#define   _BPEN1()        EnableBackplanes (1, 3)
	#define   _BPEN2()        EnableBackplanes (2, 0)
	#define   _BPEN3()        EnableBackplanes (3, 0)

/*
SetBackplane
 Give the COM number  to the previous enable Backplane     
param: ComNum -- COM number     LCDpin --- LCDn number of pin that its connected  
*/
	#define   _SETCOM1()        SetBackplane (0, 0)
	#define   _SETCOM2()        SetBackplane (1, 3)
	#define   _SETCOM3()        SetBackplane (2, 6)
	#define   _SETCOM4()        SetBackplane (3, 9)
	#define   _SETCOM5()        SetBackplane (4, 1)
	#define   _SETCOM6()        SetBackplane (5, 7)
	#define   _SETCOM7()        SetBackplane (6, 4)
	#define   _SETCOM8()        SetBackplane (7, 8)

/**
Character place
This macro defines the LDCWavefroms directions needed for write the alphanumerics        
param:  LCDpin --- LCDn number of pin that its connected */
	#define   CHAR1B       (5)
	#define   CHAR1A       (2)
	#define   CHAR2B       (11)
	#define   CHAR2A       (14)
	#define   CHAR3B       (10)
	#define   CHAR3A       (12)
	#define   CHAR4B       (13)
	#define   CHAR4A       (15)
	#define   CHAR9A       (31)
	#define   CHAR9B       (17)
	#define   CHAR8A       (20)
	#define   CHAR8B       (23)
	#define   CHAR7A       (25)
	#define   CHAR7B       (24)
	#define   CHAR6A       (22)
	#define   CHAR6B       (21)
	#define   CHAR5A       (19)
	#define   CHAR5B       (18)

/**
AllSegmentsON
Turns on all the segments of the custom glass   
param: LCDn -- LCDWF that needs to be turn on	ComMask -- Bits that are turn on example: 8 COM = 255   2 COM = 3 */
	#define SEGMENT1_ON		    AllSegmentsON (5  , 255 )
	#define SEGMENT2_ON			AllSegmentsON (2  , 255 )
	#define SEGMENT3_ON			AllSegmentsON (11 , 255 )
	#define SEGMENT4_ON			AllSegmentsON (14 , 255 )
	#define SEGMENT5_ON			AllSegmentsON (10 , 255 )
	#define SEGMENT6_ON			AllSegmentsON (12 , 255 )
	#define SEGMENT7_ON			AllSegmentsON (13 , 255 )
	#define SEGMENT8_ON			AllSegmentsON (15 , 255 )
	#define SEGMENT9_ON			AllSegmentsON (27 , 255 )
	#define SEGMENT10_ON		AllSegmentsON (30 , 255 )
	#define SEGMENT11_ON   		AllSegmentsON (28 , 255 )
	#define SEGMENT12_ON	    AllSegmentsON (26 , 255 )
	#define SEGMENT13_ON	    AllSegmentsON (29 , 255 )
	#define SEGMENT14_ON   	 	AllSegmentsON (31 , 255 )
	#define SEGMENT15_ON	    AllSegmentsON (17 , 255 )
	#define SEGMENT16_ON   		AllSegmentsON (20 , 255 )
	#define SEGMENT17_ON	    AllSegmentsON (23 , 255 )
	#define SEGMENT18_ON	    AllSegmentsON (25 , 255 )
	#define SEGMENT19_ON	    AllSegmentsON (24 , 255 )
	#define SEGMENT20_ON	    AllSegmentsON (22 , 255 )
	#define SEGMENT21_ON	    AllSegmentsON (21 , 255 )
	#define SEGMENT22_ON	    AllSegmentsON (19 , 255 )
	#define SEGMENT23_ON	    AllSegmentsON (18 , 255 )
	#define SEGMENT24_ON    	AllSegmentsON (16 , 255 )

/**
AllSegmentsOFF
Turns on all the segments of the custom glass   
param: LCDn -- LCDWF that needs to be turn on	ComMask -- Bits that are turn on example: 8 COM = 255   2 COM = 3 */
	#define SEGMENT1_OFF       	AllSegmentsON (5  , 0 )
	#define SEGMENT2_OFF		AllSegmentsON (2  , 0 )
	#define SEGMENT3_OFF		AllSegmentsON (11 , 0 )
	#define SEGMENT4_OFF		AllSegmentsON (14 , 0 )
	#define SEGMENT5_OFF		AllSegmentsON (10 , 0 )
	#define SEGMENT6_OFF		AllSegmentsON (12 , 0 )
	#define SEGMENT7_OFF		AllSegmentsON (13 , 0 )
	#define SEGMENT8_OFF		AllSegmentsON (15 , 0 )
	#define SEGMENT9_OFF		AllSegmentsON (27 , 0 )
	#define SEGMENT10_OFF		AllSegmentsON (30 , 0 )
	#define SEGMENT11_OFF       AllSegmentsON (28 , 0 )
	#define SEGMENT12_OFF       AllSegmentsON (26 , 0 )
	#define SEGMENT13_OFF       AllSegmentsON (29 , 0 )
	#define SEGMENT14_OFF       AllSegmentsON (31 , 0 )
	#define SEGMENT15_OFF       AllSegmentsON (17 , 0 )
	#define SEGMENT16_OFF       AllSegmentsON (20 , 0 )
	#define SEGMENT17_OFF       AllSegmentsON (23 , 0 )
	#define SEGMENT18_OFF       AllSegmentsON (25 , 0 )
	#define SEGMENT19_OFF       AllSegmentsON (24 , 0 )
	#define SEGMENT20_OFF       AllSegmentsON (22 , 0 )
	#define SEGMENT21_OFF       AllSegmentsON (21 , 0 )
	#define SEGMENT22_OFF       AllSegmentsON (19 , 0 )
	#define SEGMENT23_OFF       AllSegmentsON (18 , 0 )
	#define SEGMENT24_OFF       AllSegmentsON (16 , 0 )
/* 
SymbolON
Turns on the  segment that its dedicated to write one Symbol     
param:  LCDpin --- LCDn number of pin that its connected   BitNumber -- COM Number that turns on that Symbol 
*/
	#define _LCD_PROGRAM_ON 	SymbolON(27,0)
	#define _LCD_MODE_ON 		SymbolON(27,1)
	#define _LCD_CONTRAST_ON 	SymbolON(27,2)
	#define _LCD_VOLUME_ON 		SymbolON(27,3)
	#define _LCD_DT3_ON 		SymbolON(27,4)
	#define _LCD_COL2_ON 		SymbolON(27,5)
	#define _LCD_DT4_ON 		SymbolON(27,6)
	#define _LCD_DT5_ON 		SymbolON(27,7)
	#define _LCD_PM_ON 			SymbolON(30,0)
	#define _LCD_AM_ON			SymbolON(30,1)
	#define _LCD_KWH_ON 		SymbolON(30,2)
	#define _LCD_VOL1_ON 		SymbolON(30,3)
	#define _LCD_VOL2_ON 		SymbolON(30,4)
	#define _LCD_VOL3_ON 		SymbolON(30,5)
	#define _LCD_VOL4_ON 		SymbolON(30,6)
	#define _LCD_VOL5_ON 		SymbolON(30,7)
	#define _LCD_COL4_ON 		SymbolON(28,0)
	#define _LCD_POWER_ON 		SymbolON(28,1)
	#define _LCD_VOL_ON 		SymbolON(28,2)
	#define _LCD_BATTERY_ON 	SymbolON(28,3)
	#define _LCD_BAT4_ON 		SymbolON(28,4)
	#define _LCD_BAT3_ON 		SymbolON(28,5)
	#define _LCD_BAT2_ON 		SymbolON(28,6)
	#define _LCD_BAT1_ON 		SymbolON(28,7)
	#define _LCD_M5_ON			SymbolON(26,0)
	#define _LCD_M4_ON 			SymbolON(26,1)
	#define _LCD_M3_ON 			SymbolON(26,2)
	#define _LCD_M2_ON			SymbolON(26,3)
	#define _LCD_M1_ON 			SymbolON(26,4)
	#define _LCD_M8_ON 			SymbolON(26,5)
	#define _LCD_M7_ON 			SymbolON(26,6)
	#define _LCD_M6_ON			SymbolON(26,7)
	#define _LCD_AMPS_ON 		SymbolON(29,0)
	#define _LCD_VOLTS_ON 		SymbolON(29,1)
	#define _LCD_OHMS_ON 		SymbolON(29,2)
	#define _LCD_DT8_ON 		SymbolON(29,3)
	#define _LCD_COL3_ON 		SymbolON(29,4)
	#define _LCD_DT6_ON 		SymbolON(29,5)
	#define _LCD_DT7_ON 		SymbolON(29,6)
	#define _LCD_CLOCK_ON 		SymbolON(29,7)
	#define _LCD_FREESCALE_ON 	SymbolON(16,0)
	#define _LCD_MINUS_ON 		SymbolON(16,1)
	#define _LCD_TIME_ON 		SymbolON(16,2)
	#define _LCD_DATE_ON 		SymbolON(16,3)
	#define _LCD_TEMP_ON 		SymbolON(16,4)
	#define _LCD_COL1_ON 		SymbolON(16,5)
	#define _LCD_DT1_ON 		SymbolON(16,6)
	#define _LCD_DT2_ON 		SymbolON(16,7)

/*
SymbolOFF
 Turns off the  segment   that its dedicated to write one Symbol     
param:  LCDpin --- LCDn number of pin that its connected   BitNumber -- COM Number that turns off that Symbol 
*/
	#define   _LCD_PROGRAM_OFF 	SymbolOFF(27,0)
	#define   _LCD_MODE_OFF 	SymbolOFF(27,1)
	#define   _LCD_CONTRAST_OFF SymbolOFF(27,2)
	#define   _LCD_VOLUME_OFF 	SymbolOFF(27,3)
	#define   _LCD_DT3_OFF 		SymbolOFF(27,4)
	#define   _LCD_COL2_OFF 	SymbolOFF(27,5)
	#define   _LCD_DT4_OFF 		SymbolOFF(27,6)
	#define   _LCD_DT5_OFF 		SymbolOFF(27,7)
	#define   _LCD_PM_OFF 		SymbolOFF(30,0)
	#define   _LCD_AM_OFF 		SymbolOFF(30,1)
	#define   _LCD_KWH_OFF 		SymbolOFF(30,2)
	#define   _LCD_VOL1_OFF 	SymbolOFF(30,3)
	#define   _LCD_VOL2_OFF 	SymbolOFF(30,4)
	#define   _LCD_VOL3_OFF 	SymbolOFF(30,5)
	#define   _LCD_VOL4_OFF 	SymbolOFF(30,6)
	#define   _LCD_VOL5_OFF 	SymbolOFF(30,7)
	#define   _LCD_COL4_OFF 	SymbolOFF(28,0)
	#define   _LCD_POWER_OFF 	SymbolOFF(28,1)
	#define   _LCD_VOL_OFF 		SymbolOFF(28,2)
	#define   _LCD_BATTERY_OFF 	SymbolOFF(28,3)
	#define   _LCD_BAT4_OFF 	SymbolOFF(28,4)
	#define   _LCD_BAT3_OFF 	SymbolOFF(28,5)
	#define   _LCD_BAT2_OFF 	SymbolOFF(28,6)
	#define   _LCD_BAT1_OFF 	SymbolOFF(28,7)
	#define   _LCD_M5_OFF 		SymbolOFF(26,0)
	#define   _LCD_M4_OFF 		SymbolOFF(26,1)
	#define   _LCD_M3_OFF 		SymbolOFF(26,2)
	#define   _LCD_M2_OFF 		SymbolOFF(26,3)
	#define   _LCD_M1_OFF 		SymbolOFF(26,4)
	#define   _LCD_M8_OFF 		SymbolOFF(26,5)
	#define   _LCD_M7_OFF 		SymbolOFF(26,6)
	#define   _LCD_M6_OFF 		SymbolOFF(26,7)
	#define   _LCD_AMPS_OFF 	SymbolOFF(29,0)
	#define   _LCD_VOLTS_OFF 	SymbolOFF(29,1)
	#define   _LCD_OHMS_OFF 	SymbolOFF(29,2)
	#define   _LCD_DT8_OFF 		SymbolOFF(29,3)
	#define   _LCD_COL3_OFF 	SymbolOFF(29,4)
	#define   _LCD_DT6_OFF	 	SymbolOFF(29,5)
	#define   _LCD_DT7_OFF 		SymbolOFF(29,6)
	#define   _LCD_CLOCK_OFF 	SymbolOFF(29,7)
	#define   _LCD_FREESCALE_OFF SymbolOFF(16,0)
	#define   _LCD_MINUS_OFF 	SymbolOFF(16,1)
	#define   _LCD_TIME_OFF 	SymbolOFF(16,2)
	#define   _LCD_DATE_OFF 	SymbolOFF(16,3)
	#define   _LCD_TEMP_OFF 	SymbolOFF(16,4)
	#define   _LCD_COL1_OFF 	SymbolOFF(16,5)
	#define   _LCD_DT1_OFF 		SymbolOFF(16,6)
	#define   _LCD_DT2_OFF 		SymbolOFF(16,7)

/*
MapSegments
Give the apropiate mask to set one segment of the display
param: BitNumber  -- Number of bit that needs to be turn on
*/ 
#define  SEG1         MapSegment (0)
#define  SEG2         MapSegment (1)
#define  SEG3         MapSegment (2)
#define  SEG4         MapSegment (3)
#define  SEG5         MapSegment (4)
#define  SEG6         MapSegment (5)
#define  SEG7         MapSegment (6)
#define  SEG8         MapSegment (7)

/*
Name Segments 
Create a mask to turn on alphanumeric segments
*/ 
#define SEGP        SEG1
#define SEGB        SEG2
#define SEGK        SEG3
#define SEGG        SEG4
#define SEGC        SEG5
#define SEGI        SEG6
#define SEGM        SEG7
#define SEGD        SEG8
#define SEGA        SEG1
#define SEGF        SEG2
#define SEGH        SEG3
#define SEGJ        SEG4
#define SEGL        SEG5
#define SEGE        SEG6
#define SEGN        SEG7
#define SEGO        SEG8

#define _Backupa	SEGP + SEGB + SEGK + SEGG + SEGC + SEGI + SEGM + SEGD
#define _Backupb	SEGA + SEGF +SEGH + SEGJ + SEGL + SEGE + SEGN + SEGO

//Ascii table DEMO9S09LL16
#define _0			(  SEGP +  SEGB + !SEGK + !SEGG +  SEGC + !SEGI + !SEGM +  SEGD ) ,     (  SEGA +  SEGF + !SEGH + !SEGJ + !SEGL +  SEGE + !SEGN +  SEGO ) ,   //Char = 0 ,   offset =0
#define _1			( !SEGP +  SEGB + !SEGK + !SEGG +  SEGC + !SEGI + !SEGM + !SEGD ) ,     ( !SEGA + !SEGF + !SEGH + !SEGJ + !SEGL + !SEGE + !SEGN + !SEGO ) ,   //Char = 1 ,   offset =2
#define _2			(  SEGP +  SEGB + !SEGK +  SEGG + !SEGC + !SEGI + !SEGM +  SEGD ) ,     (  SEGA + !SEGF + !SEGH + !SEGJ +  SEGL +  SEGE + !SEGN +  SEGO ) ,   //Char = 2 ,   offset =4
#define _3			(  SEGP +  SEGB + !SEGK +  SEGG +  SEGC + !SEGI + !SEGM +  SEGD ) ,     (  SEGA + !SEGF + !SEGH + !SEGJ +  SEGL + !SEGE + !SEGN +  SEGO ) ,   //Char = 3 ,   offset =6
#define _4			( !SEGP +  SEGB + !SEGK +  SEGG +  SEGC + !SEGI + !SEGM + !SEGD ) ,     ( !SEGA +  SEGF + !SEGH + !SEGJ +  SEGL + !SEGE + !SEGN + !SEGO ) ,   //Char = 4 ,   offset =8
#define _5			(  SEGP + !SEGB + !SEGK +  SEGG +  SEGC + !SEGI + !SEGM +  SEGD ) ,     (  SEGA +  SEGF + !SEGH + !SEGJ +  SEGL + !SEGE + !SEGN +  SEGO ) ,   //Char = 5 ,   offset =10
#define _6			( !SEGP + !SEGB + !SEGK +  SEGG +  SEGC + !SEGI + !SEGM +  SEGD ) ,     ( !SEGA +  SEGF + !SEGH + !SEGJ +  SEGL +  SEGE + !SEGN +  SEGO ) ,   //Char = 6 ,   offset =12
#define _7			(  SEGP +  SEGB + !SEGK + !SEGG +  SEGC + !SEGI + !SEGM + !SEGD ) ,     (  SEGA + !SEGF + !SEGH + !SEGJ + !SEGL + !SEGE + !SEGN + !SEGO ) ,   //Char = 7 ,   offset =14
#define _8			(  SEGP +  SEGB + !SEGK +  SEGG +  SEGC + !SEGI + !SEGM +  SEGD ) ,     (  SEGA +  SEGF + !SEGH + !SEGJ +  SEGL +  SEGE + !SEGN +  SEGO ) ,   //Char = 8 ,   offset =16
#define _9			(  SEGP +  SEGB + !SEGK +  SEGG +  SEGC + !SEGI + !SEGM + !SEGD ) ,     (  SEGA +  SEGF + !SEGH + !SEGJ +  SEGL + !SEGE + !SEGN + !SEGO ) ,   //Char = 9 ,   offset =18
#define _AllOff		( !SEGP + !SEGB + !SEGK + !SEGG + !SEGC + !SEGI + !SEGM + !SEGD ) ,     ( !SEGA + !SEGF + !SEGH + !SEGJ + !SEGL + !SEGE + !SEGN + !SEGO ) ,   //Char = : ,   offset =20
#define _SemiColon	( !SEGP + !SEGB + !SEGK +  SEGG + !SEGC +  SEGI + !SEGM + !SEGD ) ,     ( !SEGA + !SEGF + !SEGH + !SEGJ + !SEGL + !SEGE + !SEGN + !SEGO ) ,   //Char = ; ,   offset =22
#define _MinusThan	( !SEGP + !SEGB +  SEGK + !SEGG + !SEGC +  SEGI + !SEGM + !SEGD ) ,     ( !SEGA + !SEGF + !SEGH + !SEGJ + !SEGL + !SEGE + !SEGN + !SEGO ) ,   //Char = < ,   offset =24
#define _Equal		(  SEGP + !SEGB + !SEGK +  SEGG + !SEGC + !SEGI + !SEGM + !SEGD ) ,     (  SEGA + !SEGF + !SEGH + !SEGJ +  SEGL + !SEGE + !SEGN + !SEGO ) ,   //Char = = ,   offset =26
#define _GreaterThan ( !SEGP + !SEGB + !SEGK + !SEGG + !SEGC + !SEGI + !SEGM + !SEGD ) ,     ( !SEGA + !SEGF +  SEGH + !SEGJ + !SEGL + !SEGE +  SEGN + !SEGO ) ,   //Char = > ,   offset =28
#define _Question	(  SEGP +  SEGB + !SEGK +  SEGG + !SEGC + !SEGI + !SEGM + !SEGD ) ,     (  SEGA + !SEGF + !SEGH + !SEGJ +  SEGL +  SEGE + !SEGN + !SEGO ) ,   //Char = ? ,   offset =30
#define _AllOn		(  SEGP +  SEGB +  SEGK +  SEGG +  SEGC +  SEGI +  SEGM +  SEGD ) ,     (  SEGA +  SEGF +  SEGH +  SEGJ +  SEGL +  SEGE +  SEGN +  SEGO ) ,   //Char = @ ,   offset =32
#define _A			(  SEGP +  SEGB + !SEGK +  SEGG +  SEGC + !SEGI + !SEGM + !SEGD ) ,     (  SEGA +  SEGF + !SEGH + !SEGJ +  SEGL +  SEGE + !SEGN + !SEGO ) ,   //Char = A ,   offset =34
#define _B			(  SEGP +  SEGB + !SEGK +  SEGG +  SEGC + !SEGI + !SEGM +  SEGD ) ,     (  SEGA +  SEGF + !SEGH + !SEGJ +  SEGL +  SEGE + !SEGN +  SEGO ) ,   //Char = B ,   offset =36
#define _C			(  SEGP + !SEGB + !SEGK + !SEGG + !SEGC + !SEGI + !SEGM +  SEGD ) ,     (  SEGA +  SEGF + !SEGH + !SEGJ + !SEGL +  SEGE + !SEGN +  SEGO ) ,   //Char = C ,   offset =38
#define _D			(  SEGP +  SEGB + !SEGK + !SEGG +  SEGC + !SEGI + !SEGM +  SEGD ) ,     (  SEGA +  SEGF + !SEGH + !SEGJ + !SEGL +  SEGE + !SEGN +  SEGO ) ,   //Char = D ,   offset =40
#define _E			(  SEGP + !SEGB + !SEGK +  SEGG + !SEGC + !SEGI + !SEGM +  SEGD ) ,     (  SEGA +  SEGF + !SEGH + !SEGJ +  SEGL +  SEGE + !SEGN +  SEGO ) ,   //Char = E ,   offset =42
#define _F			(  SEGP + !SEGB + !SEGK +  SEGG + !SEGC + !SEGI + !SEGM + !SEGD ) ,     (  SEGA +  SEGF + !SEGH + !SEGJ +  SEGL +  SEGE + !SEGN + !SEGO ) ,   //Char = F ,   offset =44
#define _G			(  SEGP + !SEGB + !SEGK +  SEGG +  SEGC + !SEGI + !SEGM +  SEGD ) ,     (  SEGA +  SEGF + !SEGH + !SEGJ +  SEGL +  SEGE + !SEGN +  SEGO ) ,   //Char = G ,   offset =46
#define _H			( !SEGP +  SEGB + !SEGK +  SEGG +  SEGC + !SEGI + !SEGM + !SEGD ) ,     ( !SEGA +  SEGF + !SEGH + !SEGJ +  SEGL +  SEGE + !SEGN + !SEGO ) ,   //Char = H ,   offset =48
#define _I			( !SEGP + !SEGB + !SEGK + !SEGG + !SEGC + !SEGI +  SEGM + !SEGD ) ,     ( !SEGA + !SEGF + !SEGH +  SEGJ + !SEGL + !SEGE + !SEGN + !SEGO ) ,   //Char = I ,   offset =50
#define _J			( !SEGP +  SEGB + !SEGK + !SEGG +  SEGC + !SEGI + !SEGM +  SEGD ) ,     ( !SEGA + !SEGF + !SEGH + !SEGJ + !SEGL + !SEGE + !SEGN +  SEGO ) ,   //Char = J ,   offset =52
#define _K			( !SEGP + !SEGB +  SEGK +  SEGG + !SEGC +  SEGI + !SEGM + !SEGD ) ,     ( !SEGA +  SEGF + !SEGH + !SEGJ +  SEGL +  SEGE + !SEGN + !SEGO ) ,   //Char = K ,   offset =54
#define _L			( !SEGP + !SEGB + !SEGK + !SEGG + !SEGC + !SEGI + !SEGM +  SEGD ) ,     ( !SEGA +  SEGF + !SEGH + !SEGJ + !SEGL +  SEGE + !SEGN +  SEGO ) ,   //Char = L ,   offset =56
#define _M			( !SEGP +  SEGB +  SEGK + !SEGG +  SEGC + !SEGI + !SEGM + !SEGD ) ,     ( !SEGA +  SEGF +  SEGH + !SEGJ + !SEGL +  SEGE + !SEGN + !SEGO ) ,   //Char = M ,   offset =58
#define _N			( !SEGP +  SEGB + !SEGK + !SEGG +  SEGC +  SEGI + !SEGM + !SEGD ) ,     ( !SEGA +  SEGF +  SEGH + !SEGJ + !SEGL +  SEGE + !SEGN + !SEGO ) ,   //Char = N ,   offset =60
#define _O			(  SEGP +  SEGB + !SEGK + !SEGG +  SEGC + !SEGI + !SEGM +  SEGD ) ,     (  SEGA +  SEGF + !SEGH + !SEGJ + !SEGL +  SEGE + !SEGN +  SEGO ) ,   //Char = O ,   offset =62
#define _P			(  SEGP +  SEGB + !SEGK +  SEGG + !SEGC + !SEGI + !SEGM + !SEGD ) ,     (  SEGA +  SEGF + !SEGH + !SEGJ +  SEGL +  SEGE + !SEGN + !SEGO ) ,   //Char = P ,   offset =64
#define _Q			(  SEGP +  SEGB + !SEGK +  SEGG +  SEGC + !SEGI + !SEGM +  SEGD ) ,     (  SEGA +  SEGF + !SEGH + !SEGJ +  SEGL +  SEGE + !SEGN +  SEGO ) ,   //Char = Q ,   offset =66
#define _R			(  SEGP +  SEGB + !SEGK +  SEGG + !SEGC +  SEGI + !SEGM + !SEGD ) ,     (  SEGA +  SEGF + !SEGH + !SEGJ +  SEGL +  SEGE + !SEGN + !SEGO ) ,   //Char = R ,   offset =68
#define _S			(  SEGP + !SEGB + !SEGK +  SEGG +  SEGC + !SEGI + !SEGM +  SEGD ) ,     (  SEGA +  SEGF + !SEGH + !SEGJ +  SEGL + !SEGE + !SEGN +  SEGO ) ,   //Char = S ,   offset =70
#define _T			(  SEGP + !SEGB + !SEGK + !SEGG + !SEGC + !SEGI +  SEGM + !SEGD ) ,     (  SEGA + !SEGF + !SEGH +  SEGJ + !SEGL + !SEGE + !SEGN + !SEGO ) ,   //Char = T ,   offset =72
#define _U			( !SEGP +  SEGB + !SEGK + !SEGG +  SEGC + !SEGI + !SEGM +  SEGD ) ,     ( !SEGA +  SEGF + !SEGH + !SEGJ + !SEGL +  SEGE + !SEGN +  SEGO ) ,   //Char = U ,   offset =74
#define _V			( !SEGP +  SEGB + !SEGK + !SEGG +  SEGC +  SEGI + !SEGM + !SEGD ) ,     ( !SEGA + !SEGF +  SEGH + !SEGJ + !SEGL + !SEGE + !SEGN + !SEGO ) ,   //Char = V ,   offset =76
#define _W			( !SEGP +  SEGB + !SEGK + !SEGG +  SEGC + !SEGI +  SEGM +  SEGD ) ,     ( !SEGA +  SEGF + !SEGH +  SEGJ + !SEGL +  SEGE + !SEGN +  SEGO ) ,   //Char = W ,   offset =78
#define _X			( !SEGP + !SEGB +  SEGK + !SEGG + !SEGC +  SEGI + !SEGM + !SEGD ) ,     ( !SEGA + !SEGF +  SEGH + !SEGJ + !SEGL + !SEGE +  SEGN + !SEGO ) ,   //Char = X ,   offset =80
#define _Y			( !SEGP + !SEGB +  SEGK + !SEGG + !SEGC + !SEGI +  SEGM + !SEGD ) ,     ( !SEGA + !SEGF +  SEGH + !SEGJ + !SEGL + !SEGE + !SEGN + !SEGO ) ,   //Char = Y ,   offset =82
#define _Z			(  SEGP +  SEGB + !SEGK +  SEGG + !SEGC + !SEGI + !SEGM +  SEGD ) ,     (  SEGA + !SEGF + !SEGH + !SEGJ + !SEGL + !SEGE +  SEGN +  SEGO )     //Char = Z ,   offset =84

/*****************************************************************************************************
* Declaration of project wide FUNCTIONS
*****************************************************************************************************/

/*****************************************************************************************************
* Declaration of module wide FUNCTIONs - NOT for use in other modules
*****************************************************************************************************/

#endif /* __LCD_HAL_H */


